@@ -1,22 +1,11 @@
-#if defined _FreeBSD_ || defined _BSDI_ || defined __OpenBSD__ || defined __NetBSD__
-#define HAVE_SOCKADDR_SA_LEN 1
-#endif
+#include "EXTERN.h"
+#include "perl.h"
 
 #include <sys/param.h>
 #include <sys/file.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
-
-#ifdef _BSDI_
-#define CTL_NET 4
-#include <sys/cdefs.h>
-__BEGIN_DECLS
-int     sysctl __P((int *, u_int, void *, size_t *, const void *, size_t));
-__END_DECLS
-#else
 #include <sys/sysctl.h>
-#endif /*_BSDI_*/
-
 #include <net/if.h>
 #include <net/route.h>
 #include <net/if_dl.h>
@@ -132,16 +121,13 @@ ip_rt_dev(u_int32_t addr,u_char *name)
 	mib[4] = NET_RT_DUMP;
 	mib[5] = 0;		
 	if (sysctl(mib, 6, NULL, &needed, NULL, 0) < 0){
-		perror("route-sysctl-estimate");
-                exit(-1);
+		croak("route-sysctl-estimate");
         }
 	if ((buf = malloc(needed)) == NULL){
-		perror("malloc");
-                exit(-1);
+		croak("malloc");
         } 
 	if (sysctl(mib, 6, buf, &needed, NULL, 0) < 0){
-		 perror("route-sysctl-get");
-                 exit(-1);
+		croak("route-sysctl-get");
         }
 	lim = buf + needed;
 	for (next = buf; next < lim; next += rtm->rtm_msglen) {
@@ -190,6 +176,7 @@ ip_rt_dev(u_int32_t addr,u_char *name)
                                 }
     }
    }
+   free(buf);
   return  dev_name(devip,name);
 }
 
